@@ -146,18 +146,20 @@ func (b *SharedBuffer) remove(start, end Loc) []byte {
 func (b *SharedBuffer) MarkModified(start, end int) {
 	b.ModifiedThisFrame = true
 
-	if !b.Settings["syntax"].(bool) || b.SyntaxDef == nil {
-		return
-	}
-
 	start = util.Clamp(start, 0, len(b.lines)-1)
 	end = util.Clamp(end, 0, len(b.lines)-1)
 
-	l := -1
+	if b.Settings["syntax"].(bool) && b.SyntaxDef != nil {
+		l := -1
+		for i := start; i <= end; i++ {
+			l = util.Max(b.Highlighter.ReHighlightStates(b, i), l)
+		}
+		b.Highlighter.HighlightMatches(b, start, l)
+	}
+
 	for i := start; i <= end; i++ {
-		l = util.Max(b.Highlighter.ReHighlightStates(b, i), l)
+		b.LineArray.invalidateSearchMatches(i)
 	}
-	b.Highlighter.HighlightMatches(b, start, l)
 }
 
 // DisableReload disables future reloads of this sharedbuffer
@@ -181,6 +183,7 @@ type DiffStatus byte
 // The syntax highlighting info must be stored with the buffer because the syntax
 // highlighter attaches information to each line of the buffer for optimization
 // purposes so it doesn't have to rehighlight everything on every update.
+// Likewise for the search highlighting.
 type Buffer struct {
 	*EventHandler
 	*SharedBuffer
@@ -202,6 +205,12 @@ type Buffer struct {
 	// This is hacky. Maybe it would be better to move all the visual x logic
 	// from buffer to display, but it would require rewriting a lot of code.
 	GetVisualX func(loc Loc) int
+
+	// Last search stores the last successful search
+	LastSearch      string
+	LastSearchRegex bool
+	// HighlightSearch enables highlighting all instances of the last successful search
+	HighlightSearch bool
 }
 
 // NewBufferFromFileAtLoc opens a new buffer with a given cursor location
@@ -256,7 +265,7 @@ func NewBufferFromFileAtLoc(path string, btype BufType, cursorLoc Loc) (*Buffer,
 	}
 
 	if readonly && prompt != nil {
-		prompt.Message("Warning: file is readonly - sudo will be attempted when saving")
+		prompt.Message(fmt.Sprintf("Warning: file is readonly - %s will be attempted when saving", config.GlobalSettings["sucmd"].(string)))
 		// buf.SetOptionNative("readonly", true)
 	}
 
@@ -287,7 +296,10 @@ func NewBufferFromString(text, path string, btype BufType) *Buffer {
 // Places the cursor at startcursor. If startcursor is -1, -1 places the
 // cursor at an autodetected location (based on savecursor or :LINE:COL)
 func NewBuffer(r io.Reader, size int64, path string, startcursor Loc, btype BufType) *Buffer {
-	absPath, _ := filepath.Abs(path)
+	absPath, err := filepath.Abs(path)
+	if err != nil {
+		absPath = path
+	}
 
 	b := new(Buffer)
 
@@ -325,7 +337,7 @@ func NewBuffer(r io.Reader, size int64, path string, startcursor Loc, btype BufT
 				b.Settings[k] = v
 			}
 		}
-		config.InitLocalSettings(settings, path)
+		config.InitLocalSettings(settings, absPath)
 		b.Settings["readonly"] = settings["readonly"]
 		b.Settings["filetype"] = settings["filetype"]
 		b.Settings["syntax"] = settings["syntax"]
@@ -408,7 +420,7 @@ func NewBuffer(r io.Reader, size int64, path string, startcursor Loc, btype BufT
 		}
 	}
 
-	err := config.RunPluginFn("onBufferOpen", luar.New(ulua.L, b))
+	err = config.RunPluginFn("onBufferOpen", luar.New(ulua.L, b))
 	if err != nil {
 		screen.TermMessage(err)
 	}
@@ -1199,6 +1211,12 @@ func (b *Buffer) DiffStatus(lineN int) DiffStatus {
 	return b.diff[lineN]
 }
 
+// SearchMatch returns true if the given location is within a match of the last search.
+// It is used for search highlighting
+func (b *Buffer) SearchMatch(pos Loc) bool {
+	return b.LineArray.SearchMatch(b, pos)
+}
+
 // WriteLog writes a string to the log buffer
 func WriteLog(s string) {
 	LogBuf.EventHandler.Insert(LogBuf.End(), s)
